"""Tensorflow datasets of astronomical time series."""
import astro_datasets.time_series.checksums
import astro_datasets.time_series.spcc
import astro_datasets.time_series.plasticc

"""Tensorflow datasets of astronomical images."""
import astro_datasets.images.mirabest

builders = [
    'spcc',
    'plasticc',
    'mirabest',
    'mirabest_confident',
]

__version__ = '0.1.0'



"""Adds the checksum directory to the search path of tensorflow datasets."""
import os
import tensorflow_datasets
tensorflow_datasets.download.add_checksums_dir(
    os.path.join(os.path.dirname(__file__), 'checksums'))
